| CONSURE | R Documentation |
The CONSURE package provides functions to perform the continuous and the combined approach from the dissertation of Saskia Schirmer. It can work with both, simulated and real-world data.
Nearly all functions are based on a mark_recapture_object.
A spatial point pattern can be simulated by given survival, migratory
connectivity and recovery probability using sim_contin.
Spatial point patterns of raw recoveries can be visualized by
plot_raw_recoveries. The age distribution can be visualized by
plot_age_distribution.
The continuous estimation approach first estimates the density of the point
pattern by est_kde. Then, survival can be estimated by
est_s and finally migratory connectivity by est_m
and a constant recovery probability by est_r. The function
est_parameters is a wrapper-function performing kernel density
estimation and parameter estimation at once.
All estimates can be plotted by the appropriate function:
plot_kde, plot_s, plot_m. The R^2
values of the linear model used to fit survival, migratory connectivity and
recovery probability can be plotted by plot_gof_of_lm.
The number of recovered individuals per area of origin can be summarized by
rec_inds_func.
par_grid creates a grid containing the values of a specific
function on the grid.
The uncertainty of the parameter estimates can be assessed by bootstrapping
with the function est_uncertainty. Optionally, data can be
bootstrapped before starting the estimation process using the function
init_bootstrapped_datasets. bootstrap_quantiles
calculates the 0.025- and 0.975-bootstrap quantiles. These quantiles can be
visualized in 3D with plotly_param or alternatively, as a
2D surface with a bootstrap quantile along a profile line with
plot_profile.
The following functions are used by the functions above:
bootstrap_marking_data performs the actual bootstrapping of
the marking data. get_bootstrap_parameters extracs the
parameters of the bootstrapped data sets from the mark_recapture_object as a
data frame.
The profile line is created using profile_of_parameter,
raster_param, wrap_profile_of_param,
profile_line and profile_points.
CONSURE needs projected data for some functions. Therefore,
the data will be projected from longitude/latitude (EPSG:4326) to Mollweide
projection (ESRI:54009), unless other projections are specified.
project_mark_recapture, project_df ,
project_window perform the projection.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.