get_bootstrap_parameters: Extracting bootstrapped parameters.

View source: R/get_bootstrap_parameters.R

get_bootstrap_parametersR Documentation

Extracting bootstrapped parameters.

Description

This function estimates the uncertainty of the parameters survival, migratory connectivity and recovery probability by bootstrapping the marking data.

Usage

get_bootstrap_parameters(mark_recapture_object, param)

Arguments

mark_recapture_object

object of class mark_recapture_object (see mark_recapture_object())

param

vector of characters specifying the parameter names considered for uncertainty estimation, possible values are s for survival, m for migratory connectivity and r for recovery probability. Defaults to c("s","m","r").

Value

raw bootstrap dataframe to be used in bootstrap_quantiles

Examples

{
  mro <- est_uncertainty(mro1D, "s", iterations = 2, filename = "test")
  extracted_parameter <- get_bootstrap_parameters(mro, "s")
}


SaskiaSchirmer/CONSURE documentation built on Sept. 3, 2023, 8:52 a.m.