init_bootstrapped_datasets: This function initializes a list of bootstrapped data sets...

View source: R/init_bootstrapped_datasets.R

init_bootstrapped_datasetsR Documentation

This function initializes a list of bootstrapped data sets for which in a next step the parameters may be estimated.

Description

This function initializes a list of bootstrapped data sets for which in a next step the parameters may be estimated.

Usage

init_bootstrapped_datasets(iterations = 1000, mark_recapture_object, filename)

Arguments

iterations

number of bootstraps

mark_recapture_object

object of class mark_recapture_object (see mark_recapture_object())

filename

(path to file) and filename to store list of bootstrapped data.

Value

list of bootstrapped datasets

Examples

bootstrap_mro <- init_bootstrapped_datasets(
  mark_recapture_object = mro1D,
  filename = "mro1D_bootstrap_raw"
)


SaskiaSchirmer/CONSURE documentation built on Sept. 3, 2023, 8:52 a.m.