plot_msr: plot initial situation

View source: R/plot_msr.R

plot_msrR Documentation

plot initial situation

Description

This function plots the initial functions for survival, recovery and migratory connectivity in 1D- or 2D-space.

Usage

plot_msr(mark_recapture_object, pdf = FALSE, ylim = c(0, 3))

Arguments

mark_recapture_object

object of class mark_recapture_object (see mark_recapture_object())

pdf

logical, saves image as pdf-file if TRUE. Defaults to FALSE.

ylim

vector in the form of c(ymin,ymax): limits of the y-axis. Defaults to c(0,3).

Value

depending on arguments plot as pdf or to plot device

Examples

plot_msr(mro1D)


# plot true state

SaskiaSchirmer/CONSURE documentation built on Sept. 3, 2023, 8:52 a.m.