View source: R/get_bootstrap_parameters.R
| get_bootstrap_parameters | R Documentation |
This function estimates the uncertainty of the parameters survival, migratory connectivity and recovery probability by bootstrapping the marking data.
get_bootstrap_parameters(mark_recapture_object, param)
mark_recapture_object |
object of class mark_recapture_object (see mark_recapture_object()) |
param |
vector of characters specifying the parameter names considered for uncertainty estimation, possible values are s for survival, m for migratory connectivity and r for recovery probability. Defaults to c("s","m","r"). |
raw bootstrap dataframe to be used in bootstrap_quantiles
{
mro <- est_uncertainty(mro1D, "s", iterations = 2, filename = "test")
extracted_parameter <- get_bootstrap_parameters(mro, "s")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.