View source: R/init_bootstrapped_datasets.R
| init_bootstrapped_datasets | R Documentation |
This function initializes a list of bootstrapped data sets for which in a next step the parameters may be estimated.
init_bootstrapped_datasets(iterations = 1000, mark_recapture_object, filename)
iterations |
number of bootstraps |
mark_recapture_object |
object of class mark_recapture_object (see mark_recapture_object()) |
filename |
(path to file) and filename to store list of bootstrapped data. |
list of bootstrapped datasets
bootstrap_mro <- init_bootstrapped_datasets(
mark_recapture_object = mro1D,
filename = "mro1D_bootstrap_raw"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.