| plot_msr | R Documentation |
This function plots the initial functions for survival, recovery and migratory connectivity in 1D- or 2D-space.
plot_msr(mark_recapture_object, pdf = FALSE, ylim = c(0, 3))
mark_recapture_object |
object of class mark_recapture_object (see mark_recapture_object()) |
pdf |
logical, saves image as pdf-file if TRUE. Defaults to FALSE. |
ylim |
vector in the form of c(ymin,ymax): limits of the y-axis. Defaults to c(0,3). |
depending on arguments plot as pdf or to plot device
plot_msr(mro1D)
# plot true state
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.